@@ -8,8 +8,8 @@ BigInt &BigInt::checked2(
 {
     BNCTX ctx;
 
-    if ((*BN_op)(&d_bn, &d_bn, &rhs.d_bn, &mod.d_bn, ctx) != 1)
-        throw Errno("BigInt ") << op << " failed";
+    if ((*BN_op)(d_bn, d_bn, rhs.d_bn, mod.d_bn, ctx) != 1)
+        throw Exception{} << "BigInt " << op << " failed";
 
     return *this;
 }
