@@ -10,6 +10,6 @@ void Cidr::setCidr(istream &fin)
         pushCidr(cidrPattern);
 
     if (d_cidr.empty())
-        throw Errno(1, "Cidr: ") << "no CIDR patterns found on "
+        throw Exception{1} << "Cidr: " << "no CIDR patterns found on "
                                         "cidr-specifications stream";
 }
