@@ -1,6 +1,6 @@
 #include "configfile.ih"
 
-vector<string>::const_iterator ConfigFile__::find(string const &target) const
+vector<string>::const_iterator ConfigFile_::find(string const &target) const
 {
     return find_if(
                 begin(), end(), 
