@@ -1,4 +1,4 @@
 inline DateTime DateTime::utc() const
 {
-    return DateTime{ d_time, UTC };
+    return DateTime{ d_utcSec, UTC };
 }
