@@ -2,13 +2,13 @@
 
 int DecryptBuf::overflow(int ch)
 {
-    update();
-    open();
+    flushBuffer();
 
     if (ch != EOF)
     {
         *pptr() = ch;         
         pbump(1);
     }
+
     return ch;
 }
