@@ -3,6 +3,6 @@
 void Hostname::init()
 {
     if (addressType() != AF_INET)
-        throw Exception() << 
+        throw Exception{} << 
                 "Hostname::init(): no AF_INET address type found";
 }
