@@ -2,6 +2,6 @@ template <CryptType type>
 IQuotedPrintableStream<type>::IQuotedPrintableStream(std::istream &in, 
                                                      size_t bufSize)
 :
-    IQuotedPrintableStreambuf<type>(in, bufSize),
+    IQuotedPrintableBuf<type>(in, bufSize),
     std::istream(this)
 {}
