@@ -4,7 +4,7 @@ ISharedStream::ISharedStream(
                 size_t maxSize, SharedMemory::SizeUnit sizeUnit,
                 std::ios::openmode openMode, size_t access)
 :
-    SharedStreambuf(maxSize, sizeUnit, openMode, access),
+    SharedBuf(maxSize, sizeUnit, openMode, access),
     istream(this)
 {}
 
