@@ -3,7 +3,7 @@
 int LocalClientSocket::connect()
 {
     if (::connect(socket(), sockaddrPtr(), size()) < 0)
-        throw Errno("LocalClientSocket::connect()");
+        throw Exception{} << "LocalClientSocket::connect(): " << errnodescr;
 
     return socket();
 }
