@@ -2,7 +2,7 @@
 
 MailHeaders &MailHeaders::operator=(MailHeaders &&tmp)
 {
-    fswap(*this, tmp);
+    fswap(*this, tmp, d_hdr);
     return *this;
 }
 
