@@ -1,4 +1,4 @@
 inline size_t OFoldStream::rightMargin(std::ostream const &os)
 {
-    return OFoldStreambuf::rightMargin(os.rdbuf());
+    return OFoldBuf::rightMargin(os.rdbuf());
 }
