@@ -9,8 +9,8 @@
 #include <bobcat/fork>
 
 #include <bobcat/pipe>
-#include <bobcat/ifdstreambuf>
-#include <bobcat/ofdstreambuf>
+#include <bobcat/ifdbuf>
+#include <bobcat/ofdbuf>
 #include <bobcat/ifdstream>
 
 class Spawn: public FBB::Fork, public std::ostream// , public std::istream
@@ -19,8 +19,8 @@ class Spawn: public FBB::Fork, public std::ostream// , public std::istream
 //    FBB::Pipe d_extractPipe;
 //    FBB::Pipe d_errPipe;
 
-    FBB::OFdStreambuf d_insertBuffer;
-//    FBB::IFdStreambuf d_extractBuffer;
+    FBB::OFdBuf d_insertBuffer;
+//    FBB::IFdBuf d_extractBuffer;
 //    FBB::IFdStream d_errStream;
 
     std::string d_command;
