@@ -2,7 +2,7 @@
 
 void SharedStream::memInfo(std::ostream &out, char const *end) const
 {
-    static_cast<SharedStreambuf const *>(this)->memInfo(out);
+    static_cast<SharedBuf const *>(this)->memInfo(out);
     out << end;
 }
 
