@@ -1,6 +1,6 @@
 #include "syslogbuf.ih"
 
-Priority Syslogbuf::setDefaultPriority(Priority priority)
+Priority SyslogBuf::setDefaultPriority(Priority priority)
 {
     Priority old = d_orgPriority;
     d_orgPriority = priority;
