@@ -1,13 +1,13 @@
 #include "syslogbuf.ih"
 
-Syslogbuf::Syslogbuf(std::string const &ident, 
+SyslogBuf::SyslogBuf(std::string const &ident, 
                      Priority priority, Facility facility, int option)
 :
     d_priority(priority),
-    d_orgPriority(priority),
-    d_data(0)
+    d_orgPriority(priority)
 {
     reset(ident, facility, option);
+    setp();                             // no buffer yet
 }
 
 
