@@ -1,5 +1,5 @@
 inline void SyslogStream::open(std::string const &ident, Priority priority, 
                                Facility facility, int option)
 {
-    Syslogbuf::open(ident, priority, facility, option);
+    reset(ident, priority, facility, option);
 }
