@@ -3,6 +3,6 @@
 SyslogStream::SyslogStream(string const &ident, Priority priority, 
                             Facility facility, int option)
 :
-    Syslogbuf(ident, priority, facility, option),
+    SyslogBuf(ident, priority, facility, option),
     std::ostream(this)
 {}
